# coding: utf-8

"""
    virusapi

    The Cloudmersive Virus Scan API lets you scan files and content for viruses and identify security issues with content.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CloudStorageVirusScanResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'clean_result': 'bool',
        'found_viruses': 'list[CloudStorageVirusFound]',
        'error_detailed_description': 'str',
        'file_size': 'int'
    }

    attribute_map = {
        'successful': 'Successful',
        'clean_result': 'CleanResult',
        'found_viruses': 'FoundViruses',
        'error_detailed_description': 'ErrorDetailedDescription',
        'file_size': 'FileSize'
    }

    def __init__(self, successful=None, clean_result=None, found_viruses=None, error_detailed_description=None, file_size=None):  # noqa: E501
        """CloudStorageVirusScanResult - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._clean_result = None
        self._found_viruses = None
        self._error_detailed_description = None
        self._file_size = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if clean_result is not None:
            self.clean_result = clean_result
        if found_viruses is not None:
            self.found_viruses = found_viruses
        if error_detailed_description is not None:
            self.error_detailed_description = error_detailed_description
        if file_size is not None:
            self.file_size = file_size

    @property
    def successful(self):
        """Gets the successful of this CloudStorageVirusScanResult.  # noqa: E501

        True if the operation of retrieving the file, and scanning it were successfully completed, false if the file could not be downloaded from cloud storage, or if the file could not be scanned.  Note that successful completion does not mean the file is clean; for the output of the virus scanning operation itself, use the CleanResult and FoundViruses parameters.  # noqa: E501

        :return: The successful of this CloudStorageVirusScanResult.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this CloudStorageVirusScanResult.

        True if the operation of retrieving the file, and scanning it were successfully completed, false if the file could not be downloaded from cloud storage, or if the file could not be scanned.  Note that successful completion does not mean the file is clean; for the output of the virus scanning operation itself, use the CleanResult and FoundViruses parameters.  # noqa: E501

        :param successful: The successful of this CloudStorageVirusScanResult.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def clean_result(self):
        """Gets the clean_result of this CloudStorageVirusScanResult.  # noqa: E501

        True if the scan contained no viruses, false otherwise  # noqa: E501

        :return: The clean_result of this CloudStorageVirusScanResult.  # noqa: E501
        :rtype: bool
        """
        return self._clean_result

    @clean_result.setter
    def clean_result(self, clean_result):
        """Sets the clean_result of this CloudStorageVirusScanResult.

        True if the scan contained no viruses, false otherwise  # noqa: E501

        :param clean_result: The clean_result of this CloudStorageVirusScanResult.  # noqa: E501
        :type: bool
        """

        self._clean_result = clean_result

    @property
    def found_viruses(self):
        """Gets the found_viruses of this CloudStorageVirusScanResult.  # noqa: E501

        Array of viruses found, if any  # noqa: E501

        :return: The found_viruses of this CloudStorageVirusScanResult.  # noqa: E501
        :rtype: list[CloudStorageVirusFound]
        """
        return self._found_viruses

    @found_viruses.setter
    def found_viruses(self, found_viruses):
        """Sets the found_viruses of this CloudStorageVirusScanResult.

        Array of viruses found, if any  # noqa: E501

        :param found_viruses: The found_viruses of this CloudStorageVirusScanResult.  # noqa: E501
        :type: list[CloudStorageVirusFound]
        """

        self._found_viruses = found_viruses

    @property
    def error_detailed_description(self):
        """Gets the error_detailed_description of this CloudStorageVirusScanResult.  # noqa: E501

        Detailed error message if the operation was not successful  # noqa: E501

        :return: The error_detailed_description of this CloudStorageVirusScanResult.  # noqa: E501
        :rtype: str
        """
        return self._error_detailed_description

    @error_detailed_description.setter
    def error_detailed_description(self, error_detailed_description):
        """Sets the error_detailed_description of this CloudStorageVirusScanResult.

        Detailed error message if the operation was not successful  # noqa: E501

        :param error_detailed_description: The error_detailed_description of this CloudStorageVirusScanResult.  # noqa: E501
        :type: str
        """

        self._error_detailed_description = error_detailed_description

    @property
    def file_size(self):
        """Gets the file_size of this CloudStorageVirusScanResult.  # noqa: E501

        Size in bytes of the file that was retrieved and scanned  # noqa: E501

        :return: The file_size of this CloudStorageVirusScanResult.  # noqa: E501
        :rtype: int
        """
        return self._file_size

    @file_size.setter
    def file_size(self, file_size):
        """Sets the file_size of this CloudStorageVirusScanResult.

        Size in bytes of the file that was retrieved and scanned  # noqa: E501

        :param file_size: The file_size of this CloudStorageVirusScanResult.  # noqa: E501
        :type: int
        """

        self._file_size = file_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudStorageVirusScanResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudStorageVirusScanResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    virusapi

    The Cloudmersive Virus Scan API lets you scan files and content for viruses and identify security issues with content.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from cloudmersive_virus_api_client.api.scan_api import ScanApi
from cloudmersive_virus_api_client.api.scan_cloud_storage_api import ScanCloudStorageApi

# import ApiClient
from cloudmersive_virus_api_client.api_client import ApiClient
from cloudmersive_virus_api_client.configuration import Configuration
# import models into sdk package
from cloudmersive_virus_api_client.models.cloud_storage_virus_found import CloudStorageVirusFound
from cloudmersive_virus_api_client.models.cloud_storage_virus_scan_result import CloudStorageVirusScanResult
from cloudmersive_virus_api_client.models.virus_found import VirusFound
from cloudmersive_virus_api_client.models.virus_scan_advanced_result import VirusScanAdvancedResult
from cloudmersive_virus_api_client.models.virus_scan_result import VirusScanResult
from cloudmersive_virus_api_client.models.website_scan_request import WebsiteScanRequest
from cloudmersive_virus_api_client.models.website_scan_result import WebsiteScanResult



# coding: utf-8

"""
    virusapi

    The Cloudmersive Virus Scan API lets you scan files and content for viruses and identify security issues with content.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WebsiteScanResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'clean_result': 'bool',
        'website_threat_type': 'str',
        'found_viruses': 'list[VirusFound]',
        'website_http_response_code': 'int'
    }

    attribute_map = {
        'clean_result': 'CleanResult',
        'website_threat_type': 'WebsiteThreatType',
        'found_viruses': 'FoundViruses',
        'website_http_response_code': 'WebsiteHttpResponseCode'
    }

    def __init__(self, clean_result=None, website_threat_type=None, found_viruses=None, website_http_response_code=None):  # noqa: E501
        """WebsiteScanResult - a model defined in Swagger"""  # noqa: E501

        self._clean_result = None
        self._website_threat_type = None
        self._found_viruses = None
        self._website_http_response_code = None
        self.discriminator = None

        if clean_result is not None:
            self.clean_result = clean_result
        if website_threat_type is not None:
            self.website_threat_type = website_threat_type
        if found_viruses is not None:
            self.found_viruses = found_viruses
        if website_http_response_code is not None:
            self.website_http_response_code = website_http_response_code

    @property
    def clean_result(self):
        """Gets the clean_result of this WebsiteScanResult.  # noqa: E501

        True if the scan contained no threats, false otherwise  # noqa: E501

        :return: The clean_result of this WebsiteScanResult.  # noqa: E501
        :rtype: bool
        """
        return self._clean_result

    @clean_result.setter
    def clean_result(self, clean_result):
        """Sets the clean_result of this WebsiteScanResult.

        True if the scan contained no threats, false otherwise  # noqa: E501

        :param clean_result: The clean_result of this WebsiteScanResult.  # noqa: E501
        :type: bool
        """

        self._clean_result = clean_result

    @property
    def website_threat_type(self):
        """Gets the website_threat_type of this WebsiteScanResult.  # noqa: E501

        Type of threat returned; can be None, Malware, ForcedDownload or Phishing  # noqa: E501

        :return: The website_threat_type of this WebsiteScanResult.  # noqa: E501
        :rtype: str
        """
        return self._website_threat_type

    @website_threat_type.setter
    def website_threat_type(self, website_threat_type):
        """Sets the website_threat_type of this WebsiteScanResult.

        Type of threat returned; can be None, Malware, ForcedDownload or Phishing  # noqa: E501

        :param website_threat_type: The website_threat_type of this WebsiteScanResult.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Malware", "Phishing", "ForcedDownload", "UnableToConnect"]  # noqa: E501
        if website_threat_type not in allowed_values:
            raise ValueError(
                "Invalid value for `website_threat_type` ({0}), must be one of {1}"  # noqa: E501
                .format(website_threat_type, allowed_values)
            )

        self._website_threat_type = website_threat_type

    @property
    def found_viruses(self):
        """Gets the found_viruses of this WebsiteScanResult.  # noqa: E501

        Array of viruses found, if any  # noqa: E501

        :return: The found_viruses of this WebsiteScanResult.  # noqa: E501
        :rtype: list[VirusFound]
        """
        return self._found_viruses

    @found_viruses.setter
    def found_viruses(self, found_viruses):
        """Sets the found_viruses of this WebsiteScanResult.

        Array of viruses found, if any  # noqa: E501

        :param found_viruses: The found_viruses of this WebsiteScanResult.  # noqa: E501
        :type: list[VirusFound]
        """

        self._found_viruses = found_viruses

    @property
    def website_http_response_code(self):
        """Gets the website_http_response_code of this WebsiteScanResult.  # noqa: E501

        The remote server URL HTTP reasponse code; useful for debugging issues with scanning; typically if the remote server returns a 200 or 300-series code this means a successful response, while a 400 or 500 series code would represent an error returned from the remote server for the provided URL.  # noqa: E501

        :return: The website_http_response_code of this WebsiteScanResult.  # noqa: E501
        :rtype: int
        """
        return self._website_http_response_code

    @website_http_response_code.setter
    def website_http_response_code(self, website_http_response_code):
        """Sets the website_http_response_code of this WebsiteScanResult.

        The remote server URL HTTP reasponse code; useful for debugging issues with scanning; typically if the remote server returns a 200 or 300-series code this means a successful response, while a 400 or 500 series code would represent an error returned from the remote server for the provided URL.  # noqa: E501

        :param website_http_response_code: The website_http_response_code of this WebsiteScanResult.  # noqa: E501
        :type: int
        """

        self._website_http_response_code = website_http_response_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebsiteScanResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebsiteScanResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    virusapi

    The Cloudmersive Virus Scan API lets you scan files and content for viruses and identify security issues with content.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_virus_api_client.api_client import ApiClient


class ScanCloudStorageApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def scan_cloud_storage_scan_aws_s3_file(self, access_key, secret_key, bucket_region, bucket_name, key_name, **kwargs):  # noqa: E501
        """Scan an AWS S3 file for viruses  # noqa: E501

        Scan the contents of a single AWS S3 file and its content for viruses. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_cloud_storage_scan_aws_s3_file(access_key, secret_key, bucket_region, bucket_name, key_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str access_key: AWS S3 access key for the S3 bucket; you can get this from My Security Credentials in the AWS console (required)
        :param str secret_key: AWS S3 secret key for the S3 bucket; you can get this from My Security Credentials in the AWS console (required)
        :param str bucket_region: Name of the region of the S3 bucket, such as 'US-East-1' (required)
        :param str bucket_name: Name of the S3 bucket (required)
        :param str key_name: Key name (also called file name) of the file in S3 that you wish to scan for viruses (required)
        :return: CloudStorageVirusScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.scan_cloud_storage_scan_aws_s3_file_with_http_info(access_key, secret_key, bucket_region, bucket_name, key_name, **kwargs)  # noqa: E501
        else:
            (data) = self.scan_cloud_storage_scan_aws_s3_file_with_http_info(access_key, secret_key, bucket_region, bucket_name, key_name, **kwargs)  # noqa: E501
            return data

    def scan_cloud_storage_scan_aws_s3_file_with_http_info(self, access_key, secret_key, bucket_region, bucket_name, key_name, **kwargs):  # noqa: E501
        """Scan an AWS S3 file for viruses  # noqa: E501

        Scan the contents of a single AWS S3 file and its content for viruses. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_cloud_storage_scan_aws_s3_file_with_http_info(access_key, secret_key, bucket_region, bucket_name, key_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str access_key: AWS S3 access key for the S3 bucket; you can get this from My Security Credentials in the AWS console (required)
        :param str secret_key: AWS S3 secret key for the S3 bucket; you can get this from My Security Credentials in the AWS console (required)
        :param str bucket_region: Name of the region of the S3 bucket, such as 'US-East-1' (required)
        :param str bucket_name: Name of the S3 bucket (required)
        :param str key_name: Key name (also called file name) of the file in S3 that you wish to scan for viruses (required)
        :return: CloudStorageVirusScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['access_key', 'secret_key', 'bucket_region', 'bucket_name', 'key_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scan_cloud_storage_scan_aws_s3_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'access_key' is set
        if ('access_key' not in params or
                params['access_key'] is None):
            raise ValueError("Missing the required parameter `access_key` when calling `scan_cloud_storage_scan_aws_s3_file`")  # noqa: E501
        # verify the required parameter 'secret_key' is set
        if ('secret_key' not in params or
                params['secret_key'] is None):
            raise ValueError("Missing the required parameter `secret_key` when calling `scan_cloud_storage_scan_aws_s3_file`")  # noqa: E501
        # verify the required parameter 'bucket_region' is set
        if ('bucket_region' not in params or
                params['bucket_region'] is None):
            raise ValueError("Missing the required parameter `bucket_region` when calling `scan_cloud_storage_scan_aws_s3_file`")  # noqa: E501
        # verify the required parameter 'bucket_name' is set
        if ('bucket_name' not in params or
                params['bucket_name'] is None):
            raise ValueError("Missing the required parameter `bucket_name` when calling `scan_cloud_storage_scan_aws_s3_file`")  # noqa: E501
        # verify the required parameter 'key_name' is set
        if ('key_name' not in params or
                params['key_name'] is None):
            raise ValueError("Missing the required parameter `key_name` when calling `scan_cloud_storage_scan_aws_s3_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'access_key' in params:
            header_params['accessKey'] = params['access_key']  # noqa: E501
        if 'secret_key' in params:
            header_params['secretKey'] = params['secret_key']  # noqa: E501
        if 'bucket_region' in params:
            header_params['bucketRegion'] = params['bucket_region']  # noqa: E501
        if 'bucket_name' in params:
            header_params['bucketName'] = params['bucket_name']  # noqa: E501
        if 'key_name' in params:
            header_params['keyName'] = params['key_name']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/virus/scan/cloud-storage/aws-s3/single', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CloudStorageVirusScanResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def scan_cloud_storage_scan_azure_blob(self, connection_string, container_name, blob_path, **kwargs):  # noqa: E501
        """Scan an Azure Blob for viruses  # noqa: E501

        Scan the contents of a single Azure Blob and its content for viruses. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_cloud_storage_scan_azure_blob(connection_string, container_name, blob_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str connection_string: Connection string for the Azure Blob Storage Account; you can get this connection string from the Access Keys tab of the Storage Account blade in the Azure Portal. (required)
        :param str container_name: Name of the Blob container within the Azure Blob Storage account (required)
        :param str blob_path: Path to the blob within the container, such as 'hello.pdf' or '/folder/subfolder/world.pdf' (required)
        :return: CloudStorageVirusScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.scan_cloud_storage_scan_azure_blob_with_http_info(connection_string, container_name, blob_path, **kwargs)  # noqa: E501
        else:
            (data) = self.scan_cloud_storage_scan_azure_blob_with_http_info(connection_string, container_name, blob_path, **kwargs)  # noqa: E501
            return data

    def scan_cloud_storage_scan_azure_blob_with_http_info(self, connection_string, container_name, blob_path, **kwargs):  # noqa: E501
        """Scan an Azure Blob for viruses  # noqa: E501

        Scan the contents of a single Azure Blob and its content for viruses. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_cloud_storage_scan_azure_blob_with_http_info(connection_string, container_name, blob_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str connection_string: Connection string for the Azure Blob Storage Account; you can get this connection string from the Access Keys tab of the Storage Account blade in the Azure Portal. (required)
        :param str container_name: Name of the Blob container within the Azure Blob Storage account (required)
        :param str blob_path: Path to the blob within the container, such as 'hello.pdf' or '/folder/subfolder/world.pdf' (required)
        :return: CloudStorageVirusScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['connection_string', 'container_name', 'blob_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scan_cloud_storage_scan_azure_blob" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'connection_string' is set
        if ('connection_string' not in params or
                params['connection_string'] is None):
            raise ValueError("Missing the required parameter `connection_string` when calling `scan_cloud_storage_scan_azure_blob`")  # noqa: E501
        # verify the required parameter 'container_name' is set
        if ('container_name' not in params or
                params['container_name'] is None):
            raise ValueError("Missing the required parameter `container_name` when calling `scan_cloud_storage_scan_azure_blob`")  # noqa: E501
        # verify the required parameter 'blob_path' is set
        if ('blob_path' not in params or
                params['blob_path'] is None):
            raise ValueError("Missing the required parameter `blob_path` when calling `scan_cloud_storage_scan_azure_blob`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'connection_string' in params:
            header_params['connectionString'] = params['connection_string']  # noqa: E501
        if 'container_name' in params:
            header_params['containerName'] = params['container_name']  # noqa: E501
        if 'blob_path' in params:
            header_params['blobPath'] = params['blob_path']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/virus/scan/cloud-storage/azure-blob/single', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CloudStorageVirusScanResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def scan_cloud_storage_scan_gcp_storage_file(self, bucket_name, object_name, json_credential_file, **kwargs):  # noqa: E501
        """Scan an Google Cloud Platform (GCP) Storage file for viruses  # noqa: E501

        Scan the contents of a single Google Cloud Platform (GCP) Storage file and its content for viruses. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_cloud_storage_scan_gcp_storage_file(bucket_name, object_name, json_credential_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_name: Name of the bucket in Google Cloud Storage (required)
        :param str object_name: Name of the object or file in Google Cloud Storage (required)
        :param file json_credential_file: Service Account credential for Google Cloud stored in a JSON file. (required)
        :return: CloudStorageVirusScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.scan_cloud_storage_scan_gcp_storage_file_with_http_info(bucket_name, object_name, json_credential_file, **kwargs)  # noqa: E501
        else:
            (data) = self.scan_cloud_storage_scan_gcp_storage_file_with_http_info(bucket_name, object_name, json_credential_file, **kwargs)  # noqa: E501
            return data

    def scan_cloud_storage_scan_gcp_storage_file_with_http_info(self, bucket_name, object_name, json_credential_file, **kwargs):  # noqa: E501
        """Scan an Google Cloud Platform (GCP) Storage file for viruses  # noqa: E501

        Scan the contents of a single Google Cloud Platform (GCP) Storage file and its content for viruses. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_cloud_storage_scan_gcp_storage_file_with_http_info(bucket_name, object_name, json_credential_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_name: Name of the bucket in Google Cloud Storage (required)
        :param str object_name: Name of the object or file in Google Cloud Storage (required)
        :param file json_credential_file: Service Account credential for Google Cloud stored in a JSON file. (required)
        :return: CloudStorageVirusScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bucket_name', 'object_name', 'json_credential_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scan_cloud_storage_scan_gcp_storage_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bucket_name' is set
        if ('bucket_name' not in params or
                params['bucket_name'] is None):
            raise ValueError("Missing the required parameter `bucket_name` when calling `scan_cloud_storage_scan_gcp_storage_file`")  # noqa: E501
        # verify the required parameter 'object_name' is set
        if ('object_name' not in params or
                params['object_name'] is None):
            raise ValueError("Missing the required parameter `object_name` when calling `scan_cloud_storage_scan_gcp_storage_file`")  # noqa: E501
        # verify the required parameter 'json_credential_file' is set
        if ('json_credential_file' not in params or
                params['json_credential_file'] is None):
            raise ValueError("Missing the required parameter `json_credential_file` when calling `scan_cloud_storage_scan_gcp_storage_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'bucket_name' in params:
            header_params['bucketName'] = params['bucket_name']  # noqa: E501
        if 'object_name' in params:
            header_params['objectName'] = params['object_name']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'json_credential_file' in params:
            local_var_files['jsonCredentialFile'] = params['json_credential_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/virus/scan/cloud-storage/gcp-storage/single', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CloudStorageVirusScanResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    virusapi

    The Cloudmersive Virus Scan API lets you scan files and content for viruses and identify security issues with content.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_virus_api_client
from cloudmersive_virus_api_client.api.scan_cloud_storage_api import ScanCloudStorageApi  # noqa: E501
from cloudmersive_virus_api_client.rest import ApiException


class TestScanCloudStorageApi(unittest.TestCase):
    """ScanCloudStorageApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_virus_api_client.api.scan_cloud_storage_api.ScanCloudStorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_scan_cloud_storage_scan_aws_s3_file(self):
        """Test case for scan_cloud_storage_scan_aws_s3_file

        Scan an AWS S3 file for viruses  # noqa: E501
        """
        pass

    def test_scan_cloud_storage_scan_azure_blob(self):
        """Test case for scan_cloud_storage_scan_azure_blob

        Scan an Azure Blob for viruses  # noqa: E501
        """
        pass

    def test_scan_cloud_storage_scan_gcp_storage_file(self):
        """Test case for scan_cloud_storage_scan_gcp_storage_file

        Scan an Google Cloud Platform (GCP) Storage file for viruses  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    virusapi

    The Cloudmersive Virus Scan API lets you scan files and content for viruses and identify security issues with content.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_virus_api_client.api_client import ApiClient


class ScanApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def scan_file(self, input_file, **kwargs):  # noqa: E501
        """Scan a file for viruses  # noqa: E501

        Scan files and content for viruses. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_file(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: VirusScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.scan_file_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.scan_file_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def scan_file_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Scan a file for viruses  # noqa: E501

        Scan files and content for viruses. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_file_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: VirusScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scan_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `scan_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/virus/scan/file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VirusScanResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def scan_file_advanced(self, input_file, **kwargs):  # noqa: E501
        """Advanced Scan a file for viruses  # noqa: E501

        Advanced Scan files with 360-degree Content Protection across Viruses and Malware, executables, invalid files, scripts, and even restrictions on accepted file types with complete content verification. Customize threat rules to your needs. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Block threats beyond viruses including executables, scripts, invalid files, and more.  Optionally limit input files to a specific set of file types (e.g. PDF and Word Documents only).  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_file_advanced(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param bool allow_executables: Set to false to block executable files (program code) from being allowed in the input file.  Default is false (recommended).
        :param bool allow_invalid_files: Set to false to block invalid files, such as a PDF file that is not really a valid PDF file, or a Word Document that is not a valid Word Document.  Default is false (recommended).
        :param bool allow_scripts: Set to false to block script files, such as a PHP files, Python scripts, and other malicious content or security threats that can be embedded in the file.  Set to true to allow these file types.  Default is false (recommended).
        :param bool allow_password_protected_files: Set to false to block password protected and encrypted files, such as encrypted zip and rar files, and other files that seek to circumvent scanning through passwords.  Set to true to allow these file types.  Default is false (recommended).
        :param bool allow_macros: Set to false to block macros and other threats embedded in document files, such as Word, Excel and PowerPoint embedded Macros, and other files that contain embedded content threats.  Set to true to allow these file types.  Default is false (recommended).
        :param str restrict_file_types: Specify a restricted set of file formats to allow as clean as a comma-separated list of file formats, such as .pdf,.docx,.png would allow only PDF, PNG and Word document files.  All files must pass content verification against this list of file formats, if they do not, then the result will be returned as CleanResult=false.  Set restrictFileTypes parameter to null or empty string to disable; default is disabled.
        :return: VirusScanAdvancedResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.scan_file_advanced_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.scan_file_advanced_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def scan_file_advanced_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Advanced Scan a file for viruses  # noqa: E501

        Advanced Scan files with 360-degree Content Protection across Viruses and Malware, executables, invalid files, scripts, and even restrictions on accepted file types with complete content verification. Customize threat rules to your needs. Leverage continuously updated signatures for millions of threats, and advanced high-performance scanning capabilities.  Over 17 million virus and malware signatures.  Continuous cloud-based updates.  Block threats beyond viruses including executables, scripts, invalid files, and more.  Optionally limit input files to a specific set of file types (e.g. PDF and Word Documents only).  Wide file format support including Office, PDF, HTML, Flash.  Zip support including .Zip, .Rar, .DMG, .Tar, and other archive formats.  Multi-threat scanning across viruses, malware, trojans, ransomware, and spyware.  High-speed in-memory scanning delivers subsecond typical response time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_file_advanced_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param bool allow_executables: Set to false to block executable files (program code) from being allowed in the input file.  Default is false (recommended).
        :param bool allow_invalid_files: Set to false to block invalid files, such as a PDF file that is not really a valid PDF file, or a Word Document that is not a valid Word Document.  Default is false (recommended).
        :param bool allow_scripts: Set to false to block script files, such as a PHP files, Python scripts, and other malicious content or security threats that can be embedded in the file.  Set to true to allow these file types.  Default is false (recommended).
        :param bool allow_password_protected_files: Set to false to block password protected and encrypted files, such as encrypted zip and rar files, and other files that seek to circumvent scanning through passwords.  Set to true to allow these file types.  Default is false (recommended).
        :param bool allow_macros: Set to false to block macros and other threats embedded in document files, such as Word, Excel and PowerPoint embedded Macros, and other files that contain embedded content threats.  Set to true to allow these file types.  Default is false (recommended).
        :param str restrict_file_types: Specify a restricted set of file formats to allow as clean as a comma-separated list of file formats, such as .pdf,.docx,.png would allow only PDF, PNG and Word document files.  All files must pass content verification against this list of file formats, if they do not, then the result will be returned as CleanResult=false.  Set restrictFileTypes parameter to null or empty string to disable; default is disabled.
        :return: VirusScanAdvancedResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'allow_executables', 'allow_invalid_files', 'allow_scripts', 'allow_password_protected_files', 'allow_macros', 'restrict_file_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scan_file_advanced" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `scan_file_advanced`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'allow_executables' in params:
            header_params['allowExecutables'] = params['allow_executables']  # noqa: E501
        if 'allow_invalid_files' in params:
            header_params['allowInvalidFiles'] = params['allow_invalid_files']  # noqa: E501
        if 'allow_scripts' in params:
            header_params['allowScripts'] = params['allow_scripts']  # noqa: E501
        if 'allow_password_protected_files' in params:
            header_params['allowPasswordProtectedFiles'] = params['allow_password_protected_files']  # noqa: E501
        if 'allow_macros' in params:
            header_params['allowMacros'] = params['allow_macros']  # noqa: E501
        if 'restrict_file_types' in params:
            header_params['restrictFileTypes'] = params['restrict_file_types']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/virus/scan/file/advanced', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VirusScanAdvancedResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def scan_website(self, input, **kwargs):  # noqa: E501
        """Scan a website for malicious content and threats  # noqa: E501

        Operation includes scanning the content of the URL for various types of malicious content and threats, including viruses and threats (including Phishing).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_website(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WebsiteScanRequest input: (required)
        :return: WebsiteScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.scan_website_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.scan_website_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def scan_website_with_http_info(self, input, **kwargs):  # noqa: E501
        """Scan a website for malicious content and threats  # noqa: E501

        Operation includes scanning the content of the URL for various types of malicious content and threats, including viruses and threats (including Phishing).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_website_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WebsiteScanRequest input: (required)
        :return: WebsiteScanResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scan_website" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `scan_website`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/virus/scan/website', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebsiteScanResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from cloudmersive_virus_api_client.api.scan_api import ScanApi
from cloudmersive_virus_api_client.api.scan_cloud_storage_api import ScanCloudStorageApi



# coding: utf-8

"""
    virusapi

    Virus API lets you scan files and content for viruses and identify security issues with content.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_virus_api_client
from cloudmersive_virus_api_client.api.scan_api import ScanApi  # noqa: E501
from cloudmersive_virus_api_client.rest import ApiException


class TestScanApi(unittest.TestCase):
    """ScanApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_virus_api_client.api.scan_api.ScanApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_scan_file(self):
        """Test case for scan_file

        Scan a file for viruses  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
